@@ -24,11 +24,12 @@ def _get_kwargs(
     script_hash: Union[Unset, None, str] = UNSET,
     started_before: Union[Unset, None, datetime.datetime] = UNSET,
     started_after: Union[Unset, None, datetime.datetime] = UNSET,
-    created_or_started_before: Union[Unset, None, datetime.datetime] = UNSET,
     running: Union[Unset, None, bool] = UNSET,
     scheduled_for_before_now: Union[Unset, None, bool] = UNSET,
-    created_or_started_after: Union[Unset, None, datetime.datetime] = UNSET,
-    created_or_started_after_completed_jobs: Union[Unset, None, datetime.datetime] = UNSET,
+    completed_before: Union[Unset, None, datetime.datetime] = UNSET,
+    completed_after: Union[Unset, None, datetime.datetime] = UNSET,
+    created_before_queue: Union[Unset, None, datetime.datetime] = UNSET,
+    created_after_queue: Union[Unset, None, datetime.datetime] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
     args: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
@@ -76,29 +77,33 @@ def _get_kwargs(
 
     params["started_after"] = json_started_after
 
-    json_created_or_started_before: Union[Unset, None, str] = UNSET
-    if not isinstance(created_or_started_before, Unset):
-        json_created_or_started_before = created_or_started_before.isoformat() if created_or_started_before else None
-
-    params["created_or_started_before"] = json_created_or_started_before
-
     params["running"] = running
 
     params["scheduled_for_before_now"] = scheduled_for_before_now
 
-    json_created_or_started_after: Union[Unset, None, str] = UNSET
-    if not isinstance(created_or_started_after, Unset):
-        json_created_or_started_after = created_or_started_after.isoformat() if created_or_started_after else None
+    json_completed_before: Union[Unset, None, str] = UNSET
+    if not isinstance(completed_before, Unset):
+        json_completed_before = completed_before.isoformat() if completed_before else None
 
-    params["created_or_started_after"] = json_created_or_started_after
+    params["completed_before"] = json_completed_before
 
-    json_created_or_started_after_completed_jobs: Union[Unset, None, str] = UNSET
-    if not isinstance(created_or_started_after_completed_jobs, Unset):
-        json_created_or_started_after_completed_jobs = (
-            created_or_started_after_completed_jobs.isoformat() if created_or_started_after_completed_jobs else None
-        )
+    json_completed_after: Union[Unset, None, str] = UNSET
+    if not isinstance(completed_after, Unset):
+        json_completed_after = completed_after.isoformat() if completed_after else None
 
-    params["created_or_started_after_completed_jobs"] = json_created_or_started_after_completed_jobs
+    params["completed_after"] = json_completed_after
+
+    json_created_before_queue: Union[Unset, None, str] = UNSET
+    if not isinstance(created_before_queue, Unset):
+        json_created_before_queue = created_before_queue.isoformat() if created_before_queue else None
+
+    params["created_before_queue"] = json_created_before_queue
+
+    json_created_after_queue: Union[Unset, None, str] = UNSET
+    if not isinstance(created_after_queue, Unset):
+        json_created_after_queue = created_after_queue.isoformat() if created_after_queue else None
+
+    params["created_after_queue"] = json_created_after_queue
 
     params["job_kinds"] = job_kinds
 
@@ -176,11 +181,12 @@ def sync_detailed(
     script_hash: Union[Unset, None, str] = UNSET,
     started_before: Union[Unset, None, datetime.datetime] = UNSET,
     started_after: Union[Unset, None, datetime.datetime] = UNSET,
-    created_or_started_before: Union[Unset, None, datetime.datetime] = UNSET,
     running: Union[Unset, None, bool] = UNSET,
     scheduled_for_before_now: Union[Unset, None, bool] = UNSET,
-    created_or_started_after: Union[Unset, None, datetime.datetime] = UNSET,
-    created_or_started_after_completed_jobs: Union[Unset, None, datetime.datetime] = UNSET,
+    completed_before: Union[Unset, None, datetime.datetime] = UNSET,
+    completed_after: Union[Unset, None, datetime.datetime] = UNSET,
+    created_before_queue: Union[Unset, None, datetime.datetime] = UNSET,
+    created_after_queue: Union[Unset, None, datetime.datetime] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
     args: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
@@ -210,11 +216,12 @@ def sync_detailed(
         script_hash (Union[Unset, None, str]):
         started_before (Union[Unset, None, datetime.datetime]):
         started_after (Union[Unset, None, datetime.datetime]):
-        created_or_started_before (Union[Unset, None, datetime.datetime]):
         running (Union[Unset, None, bool]):
         scheduled_for_before_now (Union[Unset, None, bool]):
-        created_or_started_after (Union[Unset, None, datetime.datetime]):
-        created_or_started_after_completed_jobs (Union[Unset, None, datetime.datetime]):
+        completed_before (Union[Unset, None, datetime.datetime]):
+        completed_after (Union[Unset, None, datetime.datetime]):
+        created_before_queue (Union[Unset, None, datetime.datetime]):
+        created_after_queue (Union[Unset, None, datetime.datetime]):
         job_kinds (Union[Unset, None, str]):
         args (Union[Unset, None, str]):
         tag (Union[Unset, None, str]):
@@ -250,11 +257,12 @@ def sync_detailed(
         script_hash=script_hash,
         started_before=started_before,
         started_after=started_after,
-        created_or_started_before=created_or_started_before,
         running=running,
         scheduled_for_before_now=scheduled_for_before_now,
-        created_or_started_after=created_or_started_after,
-        created_or_started_after_completed_jobs=created_or_started_after_completed_jobs,
+        completed_before=completed_before,
+        completed_after=completed_after,
+        created_before_queue=created_before_queue,
+        created_after_queue=created_after_queue,
         job_kinds=job_kinds,
         args=args,
         tag=tag,
@@ -292,11 +300,12 @@ def sync(
     script_hash: Union[Unset, None, str] = UNSET,
     started_before: Union[Unset, None, datetime.datetime] = UNSET,
     started_after: Union[Unset, None, datetime.datetime] = UNSET,
-    created_or_started_before: Union[Unset, None, datetime.datetime] = UNSET,
     running: Union[Unset, None, bool] = UNSET,
     scheduled_for_before_now: Union[Unset, None, bool] = UNSET,
-    created_or_started_after: Union[Unset, None, datetime.datetime] = UNSET,
-    created_or_started_after_completed_jobs: Union[Unset, None, datetime.datetime] = UNSET,
+    completed_before: Union[Unset, None, datetime.datetime] = UNSET,
+    completed_after: Union[Unset, None, datetime.datetime] = UNSET,
+    created_before_queue: Union[Unset, None, datetime.datetime] = UNSET,
+    created_after_queue: Union[Unset, None, datetime.datetime] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
     args: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
@@ -326,11 +335,12 @@ def sync(
         script_hash (Union[Unset, None, str]):
         started_before (Union[Unset, None, datetime.datetime]):
         started_after (Union[Unset, None, datetime.datetime]):
-        created_or_started_before (Union[Unset, None, datetime.datetime]):
         running (Union[Unset, None, bool]):
         scheduled_for_before_now (Union[Unset, None, bool]):
-        created_or_started_after (Union[Unset, None, datetime.datetime]):
-        created_or_started_after_completed_jobs (Union[Unset, None, datetime.datetime]):
+        completed_before (Union[Unset, None, datetime.datetime]):
+        completed_after (Union[Unset, None, datetime.datetime]):
+        created_before_queue (Union[Unset, None, datetime.datetime]):
+        created_after_queue (Union[Unset, None, datetime.datetime]):
         job_kinds (Union[Unset, None, str]):
         args (Union[Unset, None, str]):
         tag (Union[Unset, None, str]):
@@ -367,11 +377,12 @@ def sync(
         script_hash=script_hash,
         started_before=started_before,
         started_after=started_after,
-        created_or_started_before=created_or_started_before,
         running=running,
         scheduled_for_before_now=scheduled_for_before_now,
-        created_or_started_after=created_or_started_after,
-        created_or_started_after_completed_jobs=created_or_started_after_completed_jobs,
+        completed_before=completed_before,
+        completed_after=completed_after,
+        created_before_queue=created_before_queue,
+        created_after_queue=created_after_queue,
         job_kinds=job_kinds,
         args=args,
         tag=tag,
@@ -403,11 +414,12 @@ async def asyncio_detailed(
     script_hash: Union[Unset, None, str] = UNSET,
     started_before: Union[Unset, None, datetime.datetime] = UNSET,
     started_after: Union[Unset, None, datetime.datetime] = UNSET,
-    created_or_started_before: Union[Unset, None, datetime.datetime] = UNSET,
     running: Union[Unset, None, bool] = UNSET,
     scheduled_for_before_now: Union[Unset, None, bool] = UNSET,
-    created_or_started_after: Union[Unset, None, datetime.datetime] = UNSET,
-    created_or_started_after_completed_jobs: Union[Unset, None, datetime.datetime] = UNSET,
+    completed_before: Union[Unset, None, datetime.datetime] = UNSET,
+    completed_after: Union[Unset, None, datetime.datetime] = UNSET,
+    created_before_queue: Union[Unset, None, datetime.datetime] = UNSET,
+    created_after_queue: Union[Unset, None, datetime.datetime] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
     args: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
@@ -437,11 +449,12 @@ async def asyncio_detailed(
         script_hash (Union[Unset, None, str]):
         started_before (Union[Unset, None, datetime.datetime]):
         started_after (Union[Unset, None, datetime.datetime]):
-        created_or_started_before (Union[Unset, None, datetime.datetime]):
         running (Union[Unset, None, bool]):
         scheduled_for_before_now (Union[Unset, None, bool]):
-        created_or_started_after (Union[Unset, None, datetime.datetime]):
-        created_or_started_after_completed_jobs (Union[Unset, None, datetime.datetime]):
+        completed_before (Union[Unset, None, datetime.datetime]):
+        completed_after (Union[Unset, None, datetime.datetime]):
+        created_before_queue (Union[Unset, None, datetime.datetime]):
+        created_after_queue (Union[Unset, None, datetime.datetime]):
         job_kinds (Union[Unset, None, str]):
         args (Union[Unset, None, str]):
         tag (Union[Unset, None, str]):
@@ -477,11 +490,12 @@ async def asyncio_detailed(
         script_hash=script_hash,
         started_before=started_before,
         started_after=started_after,
-        created_or_started_before=created_or_started_before,
         running=running,
         scheduled_for_before_now=scheduled_for_before_now,
-        created_or_started_after=created_or_started_after,
-        created_or_started_after_completed_jobs=created_or_started_after_completed_jobs,
+        completed_before=completed_before,
+        completed_after=completed_after,
+        created_before_queue=created_before_queue,
+        created_after_queue=created_after_queue,
         job_kinds=job_kinds,
         args=args,
         tag=tag,
@@ -517,11 +531,12 @@ async def asyncio(
     script_hash: Union[Unset, None, str] = UNSET,
     started_before: Union[Unset, None, datetime.datetime] = UNSET,
     started_after: Union[Unset, None, datetime.datetime] = UNSET,
-    created_or_started_before: Union[Unset, None, datetime.datetime] = UNSET,
     running: Union[Unset, None, bool] = UNSET,
     scheduled_for_before_now: Union[Unset, None, bool] = UNSET,
-    created_or_started_after: Union[Unset, None, datetime.datetime] = UNSET,
-    created_or_started_after_completed_jobs: Union[Unset, None, datetime.datetime] = UNSET,
+    completed_before: Union[Unset, None, datetime.datetime] = UNSET,
+    completed_after: Union[Unset, None, datetime.datetime] = UNSET,
+    created_before_queue: Union[Unset, None, datetime.datetime] = UNSET,
+    created_after_queue: Union[Unset, None, datetime.datetime] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
     args: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
@@ -551,11 +566,12 @@ async def asyncio(
         script_hash (Union[Unset, None, str]):
         started_before (Union[Unset, None, datetime.datetime]):
         started_after (Union[Unset, None, datetime.datetime]):
-        created_or_started_before (Union[Unset, None, datetime.datetime]):
         running (Union[Unset, None, bool]):
         scheduled_for_before_now (Union[Unset, None, bool]):
-        created_or_started_after (Union[Unset, None, datetime.datetime]):
-        created_or_started_after_completed_jobs (Union[Unset, None, datetime.datetime]):
+        completed_before (Union[Unset, None, datetime.datetime]):
+        completed_after (Union[Unset, None, datetime.datetime]):
+        created_before_queue (Union[Unset, None, datetime.datetime]):
+        created_after_queue (Union[Unset, None, datetime.datetime]):
         job_kinds (Union[Unset, None, str]):
         args (Union[Unset, None, str]):
         tag (Union[Unset, None, str]):
@@ -593,11 +609,12 @@ async def asyncio(
             script_hash=script_hash,
             started_before=started_before,
             started_after=started_after,
-            created_or_started_before=created_or_started_before,
             running=running,
             scheduled_for_before_now=scheduled_for_before_now,
-            created_or_started_after=created_or_started_after,
-            created_or_started_after_completed_jobs=created_or_started_after_completed_jobs,
+            completed_before=completed_before,
+            completed_after=completed_after,
+            created_before_queue=created_before_queue,
+            created_after_queue=created_after_queue,
             job_kinds=job_kinds,
             args=args,
             tag=tag,
