@@ -24,11 +24,12 @@ def _get_kwargs(
     started_after: Union[Unset, None, datetime.datetime] = UNSET,
     created_before: Union[Unset, None, datetime.datetime] = UNSET,
     created_after: Union[Unset, None, datetime.datetime] = UNSET,
-    created_or_started_before: Union[Unset, None, datetime.datetime] = UNSET,
+    completed_before: Union[Unset, None, datetime.datetime] = UNSET,
+    completed_after: Union[Unset, None, datetime.datetime] = UNSET,
+    created_before_queue: Union[Unset, None, datetime.datetime] = UNSET,
+    created_after_queue: Union[Unset, None, datetime.datetime] = UNSET,
     running: Union[Unset, None, bool] = UNSET,
     scheduled_for_before_now: Union[Unset, None, bool] = UNSET,
-    created_or_started_after: Union[Unset, None, datetime.datetime] = UNSET,
-    created_or_started_after_completed_jobs: Union[Unset, None, datetime.datetime] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
     suspended: Union[Unset, None, bool] = UNSET,
     args: Union[Unset, None, str] = UNSET,
@@ -86,30 +87,34 @@ def _get_kwargs(
 
     params["created_after"] = json_created_after
 
-    json_created_or_started_before: Union[Unset, None, str] = UNSET
-    if not isinstance(created_or_started_before, Unset):
-        json_created_or_started_before = created_or_started_before.isoformat() if created_or_started_before else None
+    json_completed_before: Union[Unset, None, str] = UNSET
+    if not isinstance(completed_before, Unset):
+        json_completed_before = completed_before.isoformat() if completed_before else None
 
-    params["created_or_started_before"] = json_created_or_started_before
+    params["completed_before"] = json_completed_before
+
+    json_completed_after: Union[Unset, None, str] = UNSET
+    if not isinstance(completed_after, Unset):
+        json_completed_after = completed_after.isoformat() if completed_after else None
+
+    params["completed_after"] = json_completed_after
+
+    json_created_before_queue: Union[Unset, None, str] = UNSET
+    if not isinstance(created_before_queue, Unset):
+        json_created_before_queue = created_before_queue.isoformat() if created_before_queue else None
+
+    params["created_before_queue"] = json_created_before_queue
+
+    json_created_after_queue: Union[Unset, None, str] = UNSET
+    if not isinstance(created_after_queue, Unset):
+        json_created_after_queue = created_after_queue.isoformat() if created_after_queue else None
+
+    params["created_after_queue"] = json_created_after_queue
 
     params["running"] = running
 
     params["scheduled_for_before_now"] = scheduled_for_before_now
 
-    json_created_or_started_after: Union[Unset, None, str] = UNSET
-    if not isinstance(created_or_started_after, Unset):
-        json_created_or_started_after = created_or_started_after.isoformat() if created_or_started_after else None
-
-    params["created_or_started_after"] = json_created_or_started_after
-
-    json_created_or_started_after_completed_jobs: Union[Unset, None, str] = UNSET
-    if not isinstance(created_or_started_after_completed_jobs, Unset):
-        json_created_or_started_after_completed_jobs = (
-            created_or_started_after_completed_jobs.isoformat() if created_or_started_after_completed_jobs else None
-        )
-
-    params["created_or_started_after_completed_jobs"] = json_created_or_started_after_completed_jobs
-
     params["job_kinds"] = job_kinds
 
     params["suspended"] = suspended
@@ -183,11 +188,12 @@ def sync_detailed(
     started_after: Union[Unset, None, datetime.datetime] = UNSET,
     created_before: Union[Unset, None, datetime.datetime] = UNSET,
     created_after: Union[Unset, None, datetime.datetime] = UNSET,
-    created_or_started_before: Union[Unset, None, datetime.datetime] = UNSET,
+    completed_before: Union[Unset, None, datetime.datetime] = UNSET,
+    completed_after: Union[Unset, None, datetime.datetime] = UNSET,
+    created_before_queue: Union[Unset, None, datetime.datetime] = UNSET,
+    created_after_queue: Union[Unset, None, datetime.datetime] = UNSET,
     running: Union[Unset, None, bool] = UNSET,
     scheduled_for_before_now: Union[Unset, None, bool] = UNSET,
-    created_or_started_after: Union[Unset, None, datetime.datetime] = UNSET,
-    created_or_started_after_completed_jobs: Union[Unset, None, datetime.datetime] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
     suspended: Union[Unset, None, bool] = UNSET,
     args: Union[Unset, None, str] = UNSET,
@@ -218,11 +224,12 @@ def sync_detailed(
         started_after (Union[Unset, None, datetime.datetime]):
         created_before (Union[Unset, None, datetime.datetime]):
         created_after (Union[Unset, None, datetime.datetime]):
-        created_or_started_before (Union[Unset, None, datetime.datetime]):
+        completed_before (Union[Unset, None, datetime.datetime]):
+        completed_after (Union[Unset, None, datetime.datetime]):
+        created_before_queue (Union[Unset, None, datetime.datetime]):
+        created_after_queue (Union[Unset, None, datetime.datetime]):
         running (Union[Unset, None, bool]):
         scheduled_for_before_now (Union[Unset, None, bool]):
-        created_or_started_after (Union[Unset, None, datetime.datetime]):
-        created_or_started_after_completed_jobs (Union[Unset, None, datetime.datetime]):
         job_kinds (Union[Unset, None, str]):
         suspended (Union[Unset, None, bool]):
         args (Union[Unset, None, str]):
@@ -259,11 +266,12 @@ def sync_detailed(
         started_after=started_after,
         created_before=created_before,
         created_after=created_after,
-        created_or_started_before=created_or_started_before,
+        completed_before=completed_before,
+        completed_after=completed_after,
+        created_before_queue=created_before_queue,
+        created_after_queue=created_after_queue,
         running=running,
         scheduled_for_before_now=scheduled_for_before_now,
-        created_or_started_after=created_or_started_after,
-        created_or_started_after_completed_jobs=created_or_started_after_completed_jobs,
         job_kinds=job_kinds,
         suspended=suspended,
         args=args,
@@ -302,11 +310,12 @@ def sync(
     started_after: Union[Unset, None, datetime.datetime] = UNSET,
     created_before: Union[Unset, None, datetime.datetime] = UNSET,
     created_after: Union[Unset, None, datetime.datetime] = UNSET,
-    created_or_started_before: Union[Unset, None, datetime.datetime] = UNSET,
+    completed_before: Union[Unset, None, datetime.datetime] = UNSET,
+    completed_after: Union[Unset, None, datetime.datetime] = UNSET,
+    created_before_queue: Union[Unset, None, datetime.datetime] = UNSET,
+    created_after_queue: Union[Unset, None, datetime.datetime] = UNSET,
     running: Union[Unset, None, bool] = UNSET,
     scheduled_for_before_now: Union[Unset, None, bool] = UNSET,
-    created_or_started_after: Union[Unset, None, datetime.datetime] = UNSET,
-    created_or_started_after_completed_jobs: Union[Unset, None, datetime.datetime] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
     suspended: Union[Unset, None, bool] = UNSET,
     args: Union[Unset, None, str] = UNSET,
@@ -337,11 +346,12 @@ def sync(
         started_after (Union[Unset, None, datetime.datetime]):
         created_before (Union[Unset, None, datetime.datetime]):
         created_after (Union[Unset, None, datetime.datetime]):
-        created_or_started_before (Union[Unset, None, datetime.datetime]):
+        completed_before (Union[Unset, None, datetime.datetime]):
+        completed_after (Union[Unset, None, datetime.datetime]):
+        created_before_queue (Union[Unset, None, datetime.datetime]):
+        created_after_queue (Union[Unset, None, datetime.datetime]):
         running (Union[Unset, None, bool]):
         scheduled_for_before_now (Union[Unset, None, bool]):
-        created_or_started_after (Union[Unset, None, datetime.datetime]):
-        created_or_started_after_completed_jobs (Union[Unset, None, datetime.datetime]):
         job_kinds (Union[Unset, None, str]):
         suspended (Union[Unset, None, bool]):
         args (Union[Unset, None, str]):
@@ -379,11 +389,12 @@ def sync(
         started_after=started_after,
         created_before=created_before,
         created_after=created_after,
-        created_or_started_before=created_or_started_before,
+        completed_before=completed_before,
+        completed_after=completed_after,
+        created_before_queue=created_before_queue,
+        created_after_queue=created_after_queue,
         running=running,
         scheduled_for_before_now=scheduled_for_before_now,
-        created_or_started_after=created_or_started_after,
-        created_or_started_after_completed_jobs=created_or_started_after_completed_jobs,
         job_kinds=job_kinds,
         suspended=suspended,
         args=args,
@@ -416,11 +427,12 @@ async def asyncio_detailed(
     started_after: Union[Unset, None, datetime.datetime] = UNSET,
     created_before: Union[Unset, None, datetime.datetime] = UNSET,
     created_after: Union[Unset, None, datetime.datetime] = UNSET,
-    created_or_started_before: Union[Unset, None, datetime.datetime] = UNSET,
+    completed_before: Union[Unset, None, datetime.datetime] = UNSET,
+    completed_after: Union[Unset, None, datetime.datetime] = UNSET,
+    created_before_queue: Union[Unset, None, datetime.datetime] = UNSET,
+    created_after_queue: Union[Unset, None, datetime.datetime] = UNSET,
     running: Union[Unset, None, bool] = UNSET,
     scheduled_for_before_now: Union[Unset, None, bool] = UNSET,
-    created_or_started_after: Union[Unset, None, datetime.datetime] = UNSET,
-    created_or_started_after_completed_jobs: Union[Unset, None, datetime.datetime] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
     suspended: Union[Unset, None, bool] = UNSET,
     args: Union[Unset, None, str] = UNSET,
@@ -451,11 +463,12 @@ async def asyncio_detailed(
         started_after (Union[Unset, None, datetime.datetime]):
         created_before (Union[Unset, None, datetime.datetime]):
         created_after (Union[Unset, None, datetime.datetime]):
-        created_or_started_before (Union[Unset, None, datetime.datetime]):
+        completed_before (Union[Unset, None, datetime.datetime]):
+        completed_after (Union[Unset, None, datetime.datetime]):
+        created_before_queue (Union[Unset, None, datetime.datetime]):
+        created_after_queue (Union[Unset, None, datetime.datetime]):
         running (Union[Unset, None, bool]):
         scheduled_for_before_now (Union[Unset, None, bool]):
-        created_or_started_after (Union[Unset, None, datetime.datetime]):
-        created_or_started_after_completed_jobs (Union[Unset, None, datetime.datetime]):
         job_kinds (Union[Unset, None, str]):
         suspended (Union[Unset, None, bool]):
         args (Union[Unset, None, str]):
@@ -492,11 +505,12 @@ async def asyncio_detailed(
         started_after=started_after,
         created_before=created_before,
         created_after=created_after,
-        created_or_started_before=created_or_started_before,
+        completed_before=completed_before,
+        completed_after=completed_after,
+        created_before_queue=created_before_queue,
+        created_after_queue=created_after_queue,
         running=running,
         scheduled_for_before_now=scheduled_for_before_now,
-        created_or_started_after=created_or_started_after,
-        created_or_started_after_completed_jobs=created_or_started_after_completed_jobs,
         job_kinds=job_kinds,
         suspended=suspended,
         args=args,
@@ -533,11 +547,12 @@ async def asyncio(
     started_after: Union[Unset, None, datetime.datetime] = UNSET,
     created_before: Union[Unset, None, datetime.datetime] = UNSET,
     created_after: Union[Unset, None, datetime.datetime] = UNSET,
-    created_or_started_before: Union[Unset, None, datetime.datetime] = UNSET,
+    completed_before: Union[Unset, None, datetime.datetime] = UNSET,
+    completed_after: Union[Unset, None, datetime.datetime] = UNSET,
+    created_before_queue: Union[Unset, None, datetime.datetime] = UNSET,
+    created_after_queue: Union[Unset, None, datetime.datetime] = UNSET,
     running: Union[Unset, None, bool] = UNSET,
     scheduled_for_before_now: Union[Unset, None, bool] = UNSET,
-    created_or_started_after: Union[Unset, None, datetime.datetime] = UNSET,
-    created_or_started_after_completed_jobs: Union[Unset, None, datetime.datetime] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
     suspended: Union[Unset, None, bool] = UNSET,
     args: Union[Unset, None, str] = UNSET,
@@ -568,11 +583,12 @@ async def asyncio(
         started_after (Union[Unset, None, datetime.datetime]):
         created_before (Union[Unset, None, datetime.datetime]):
         created_after (Union[Unset, None, datetime.datetime]):
-        created_or_started_before (Union[Unset, None, datetime.datetime]):
+        completed_before (Union[Unset, None, datetime.datetime]):
+        completed_after (Union[Unset, None, datetime.datetime]):
+        created_before_queue (Union[Unset, None, datetime.datetime]):
+        created_after_queue (Union[Unset, None, datetime.datetime]):
         running (Union[Unset, None, bool]):
         scheduled_for_before_now (Union[Unset, None, bool]):
-        created_or_started_after (Union[Unset, None, datetime.datetime]):
-        created_or_started_after_completed_jobs (Union[Unset, None, datetime.datetime]):
         job_kinds (Union[Unset, None, str]):
         suspended (Union[Unset, None, bool]):
         args (Union[Unset, None, str]):
@@ -611,11 +627,12 @@ async def asyncio(
             started_after=started_after,
             created_before=created_before,
             created_after=created_after,
-            created_or_started_before=created_or_started_before,
+            completed_before=completed_before,
+            completed_after=completed_after,
+            created_before_queue=created_before_queue,
+            created_after_queue=created_after_queue,
             running=running,
             scheduled_for_before_now=scheduled_for_before_now,
-            created_or_started_after=created_or_started_after,
-            created_or_started_after_completed_jobs=created_or_started_after_completed_jobs,
             job_kinds=job_kinds,
             suspended=suspended,
             args=args,
