@@ -23,6 +23,7 @@ def _get_kwargs(
     job_id: Union[Unset, None, str] = UNSET,
     include_header: Union[Unset, None, str] = UNSET,
     invisible_to_owner: Union[Unset, None, bool] = UNSET,
+    memory_id: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     pass
 
@@ -47,6 +48,8 @@ def _get_kwargs(
 
     params["invisible_to_owner"] = invisible_to_owner
 
+    params["memory_id"] = memory_id
+
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
     json_json_body = json_body.to_dict()
@@ -92,6 +95,7 @@ def sync_detailed(
     job_id: Union[Unset, None, str] = UNSET,
     include_header: Union[Unset, None, str] = UNSET,
     invisible_to_owner: Union[Unset, None, bool] = UNSET,
+    memory_id: Union[Unset, None, str] = UNSET,
 ) -> Response[Any]:
     """run flow by path
 
@@ -106,6 +110,7 @@ def sync_detailed(
         job_id (Union[Unset, None, str]):
         include_header (Union[Unset, None, str]):
         invisible_to_owner (Union[Unset, None, bool]):
+        memory_id (Union[Unset, None, str]):
         json_body (RunFlowByPathJsonBody): The arguments to pass to the script or flow
 
     Raises:
@@ -128,6 +133,7 @@ def sync_detailed(
         job_id=job_id,
         include_header=include_header,
         invisible_to_owner=invisible_to_owner,
+        memory_id=memory_id,
     )
 
     response = client.get_httpx_client().request(
@@ -151,6 +157,7 @@ async def asyncio_detailed(
     job_id: Union[Unset, None, str] = UNSET,
     include_header: Union[Unset, None, str] = UNSET,
     invisible_to_owner: Union[Unset, None, bool] = UNSET,
+    memory_id: Union[Unset, None, str] = UNSET,
 ) -> Response[Any]:
     """run flow by path
 
@@ -165,6 +172,7 @@ async def asyncio_detailed(
         job_id (Union[Unset, None, str]):
         include_header (Union[Unset, None, str]):
         invisible_to_owner (Union[Unset, None, bool]):
+        memory_id (Union[Unset, None, str]):
         json_body (RunFlowByPathJsonBody): The arguments to pass to the script or flow
 
     Raises:
@@ -187,6 +195,7 @@ async def asyncio_detailed(
         job_id=job_id,
         include_header=include_header,
         invisible_to_owner=invisible_to_owner,
+        memory_id=memory_id,
     )
 
     response = await client.get_async_httpx_client().request(**kwargs)
