@@ -12,12 +12,18 @@ from ...types import UNSET, Response, Unset
 def _get_kwargs(
     *,
     exclude_ephemeral: Union[Unset, None, bool] = UNSET,
+    page: Union[Unset, None, int] = UNSET,
+    per_page: Union[Unset, None, int] = UNSET,
 ) -> Dict[str, Any]:
     pass
 
     params: Dict[str, Any] = {}
     params["exclude_ephemeral"] = exclude_ephemeral
 
+    params["page"] = page
+
+    params["per_page"] = per_page
+
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
     return {
@@ -60,11 +66,15 @@ def sync_detailed(
     *,
     client: Union[AuthenticatedClient, Client],
     exclude_ephemeral: Union[Unset, None, bool] = UNSET,
+    page: Union[Unset, None, int] = UNSET,
+    per_page: Union[Unset, None, int] = UNSET,
 ) -> Response[List["ListTokensResponse200Item"]]:
     """list token
 
     Args:
         exclude_ephemeral (Union[Unset, None, bool]):
+        page (Union[Unset, None, int]):
+        per_page (Union[Unset, None, int]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -76,6 +86,8 @@ def sync_detailed(
 
     kwargs = _get_kwargs(
         exclude_ephemeral=exclude_ephemeral,
+        page=page,
+        per_page=per_page,
     )
 
     response = client.get_httpx_client().request(
@@ -89,11 +101,15 @@ def sync(
     *,
     client: Union[AuthenticatedClient, Client],
     exclude_ephemeral: Union[Unset, None, bool] = UNSET,
+    page: Union[Unset, None, int] = UNSET,
+    per_page: Union[Unset, None, int] = UNSET,
 ) -> Optional[List["ListTokensResponse200Item"]]:
     """list token
 
     Args:
         exclude_ephemeral (Union[Unset, None, bool]):
+        page (Union[Unset, None, int]):
+        per_page (Union[Unset, None, int]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -106,6 +122,8 @@ def sync(
     return sync_detailed(
         client=client,
         exclude_ephemeral=exclude_ephemeral,
+        page=page,
+        per_page=per_page,
     ).parsed
 
 
@@ -113,11 +131,15 @@ async def asyncio_detailed(
     *,
     client: Union[AuthenticatedClient, Client],
     exclude_ephemeral: Union[Unset, None, bool] = UNSET,
+    page: Union[Unset, None, int] = UNSET,
+    per_page: Union[Unset, None, int] = UNSET,
 ) -> Response[List["ListTokensResponse200Item"]]:
     """list token
 
     Args:
         exclude_ephemeral (Union[Unset, None, bool]):
+        page (Union[Unset, None, int]):
+        per_page (Union[Unset, None, int]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -129,6 +151,8 @@ async def asyncio_detailed(
 
     kwargs = _get_kwargs(
         exclude_ephemeral=exclude_ephemeral,
+        page=page,
+        per_page=per_page,
     )
 
     response = await client.get_async_httpx_client().request(**kwargs)
@@ -140,11 +164,15 @@ async def asyncio(
     *,
     client: Union[AuthenticatedClient, Client],
     exclude_ephemeral: Union[Unset, None, bool] = UNSET,
+    page: Union[Unset, None, int] = UNSET,
+    per_page: Union[Unset, None, int] = UNSET,
 ) -> Optional[List["ListTokensResponse200Item"]]:
     """list token
 
     Args:
         exclude_ephemeral (Union[Unset, None, bool]):
+        page (Union[Unset, None, int]):
+        per_page (Union[Unset, None, int]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -158,5 +186,7 @@ async def asyncio(
         await asyncio_detailed(
             client=client,
             exclude_ephemeral=exclude_ephemeral,
+            page=page,
+            per_page=per_page,
         )
     ).parsed
