@@ -1,9 +1,10 @@
-from typing import Any, Dict, List, Type, TypeVar
+from typing import Any, Dict, List, Type, TypeVar, Union
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
 
 from ..models.branch_one_default_item_sleep_type_0_type import BranchOneDefaultItemSleepType0Type
+from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="BranchOneDefaultItemSleepType0")
 
@@ -12,39 +13,41 @@ T = TypeVar("T", bound="BranchOneDefaultItemSleepType0")
 class BranchOneDefaultItemSleepType0:
     """
     Attributes:
-        value (Any):
         type (BranchOneDefaultItemSleepType0Type):
+        value (Union[Unset, Any]):
     """
 
-    value: Any
     type: BranchOneDefaultItemSleepType0Type
+    value: Union[Unset, Any] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
-        value = self.value
         type = self.type.value
 
+        value = self.value
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
             {
-                "value": value,
                 "type": type,
             }
         )
+        if value is not UNSET:
+            field_dict["value"] = value
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
-        value = d.pop("value")
-
         type = BranchOneDefaultItemSleepType0Type(d.pop("type"))
 
+        value = d.pop("value", UNSET)
+
         branch_one_default_item_sleep_type_0 = cls(
-            value=value,
             type=type,
+            value=value,
         )
 
         branch_one_default_item_sleep_type_0.additional_properties = d
