@@ -33,6 +33,7 @@ class GetFlowByPathWithDraftResponse200DraftValueFailureModuleSuspend:
             'GetFlowByPathWithDraftResponse200DraftValueFailureModuleSuspendUserGroupsRequiredType1', Unset]):
         self_approval_disabled (Union[Unset, bool]):
         hide_cancel (Union[Unset, bool]):
+        continue_on_disapprove_timeout (Union[Unset, bool]):
     """
 
     required_events: Union[Unset, int] = UNSET
@@ -46,6 +47,7 @@ class GetFlowByPathWithDraftResponse200DraftValueFailureModuleSuspend:
     ] = UNSET
     self_approval_disabled: Union[Unset, bool] = UNSET
     hide_cancel: Union[Unset, bool] = UNSET
+    continue_on_disapprove_timeout: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -79,6 +81,7 @@ class GetFlowByPathWithDraftResponse200DraftValueFailureModuleSuspend:
 
         self_approval_disabled = self.self_approval_disabled
         hide_cancel = self.hide_cancel
+        continue_on_disapprove_timeout = self.continue_on_disapprove_timeout
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -97,6 +100,8 @@ class GetFlowByPathWithDraftResponse200DraftValueFailureModuleSuspend:
             field_dict["self_approval_disabled"] = self_approval_disabled
         if hide_cancel is not UNSET:
             field_dict["hide_cancel"] = hide_cancel
+        if continue_on_disapprove_timeout is not UNSET:
+            field_dict["continue_on_disapprove_timeout"] = continue_on_disapprove_timeout
 
         return field_dict
 
@@ -177,6 +182,8 @@ class GetFlowByPathWithDraftResponse200DraftValueFailureModuleSuspend:
 
         hide_cancel = d.pop("hide_cancel", UNSET)
 
+        continue_on_disapprove_timeout = d.pop("continue_on_disapprove_timeout", UNSET)
+
         get_flow_by_path_with_draft_response_200_draft_value_failure_module_suspend = cls(
             required_events=required_events,
             timeout=timeout,
@@ -185,6 +192,7 @@ class GetFlowByPathWithDraftResponse200DraftValueFailureModuleSuspend:
             user_groups_required=user_groups_required,
             self_approval_disabled=self_approval_disabled,
             hide_cancel=hide_cancel,
+            continue_on_disapprove_timeout=continue_on_disapprove_timeout,
         )
 
         get_flow_by_path_with_draft_response_200_draft_value_failure_module_suspend.additional_properties = d
