@@ -31,6 +31,8 @@ class GetSettingsResponse200:
         slack_name (Union[Unset, str]):
         slack_team_id (Union[Unset, str]):
         slack_command_script (Union[Unset, str]):
+        slack_oauth_client_id (Union[Unset, str]):
+        slack_oauth_client_secret (Union[Unset, str]):
         teams_team_id (Union[Unset, str]):
         teams_command_script (Union[Unset, str]):
         teams_team_name (Union[Unset, str]):
@@ -63,6 +65,8 @@ class GetSettingsResponse200:
     slack_name: Union[Unset, str] = UNSET
     slack_team_id: Union[Unset, str] = UNSET
     slack_command_script: Union[Unset, str] = UNSET
+    slack_oauth_client_id: Union[Unset, str] = UNSET
+    slack_oauth_client_secret: Union[Unset, str] = UNSET
     teams_team_id: Union[Unset, str] = UNSET
     teams_command_script: Union[Unset, str] = UNSET
     teams_team_name: Union[Unset, str] = UNSET
@@ -95,6 +99,8 @@ class GetSettingsResponse200:
         slack_name = self.slack_name
         slack_team_id = self.slack_team_id
         slack_command_script = self.slack_command_script
+        slack_oauth_client_id = self.slack_oauth_client_id
+        slack_oauth_client_secret = self.slack_oauth_client_secret
         teams_team_id = self.teams_team_id
         teams_command_script = self.teams_command_script
         teams_team_name = self.teams_team_name
@@ -164,6 +170,10 @@ class GetSettingsResponse200:
             field_dict["slack_team_id"] = slack_team_id
         if slack_command_script is not UNSET:
             field_dict["slack_command_script"] = slack_command_script
+        if slack_oauth_client_id is not UNSET:
+            field_dict["slack_oauth_client_id"] = slack_oauth_client_id
+        if slack_oauth_client_secret is not UNSET:
+            field_dict["slack_oauth_client_secret"] = slack_oauth_client_secret
         if teams_team_id is not UNSET:
             field_dict["teams_team_id"] = teams_team_id
         if teams_command_script is not UNSET:
@@ -242,6 +252,10 @@ class GetSettingsResponse200:
 
         slack_command_script = d.pop("slack_command_script", UNSET)
 
+        slack_oauth_client_id = d.pop("slack_oauth_client_id", UNSET)
+
+        slack_oauth_client_secret = d.pop("slack_oauth_client_secret", UNSET)
+
         teams_team_id = d.pop("teams_team_id", UNSET)
 
         teams_command_script = d.pop("teams_command_script", UNSET)
@@ -345,6 +359,8 @@ class GetSettingsResponse200:
             slack_name=slack_name,
             slack_team_id=slack_team_id,
             slack_command_script=slack_command_script,
+            slack_oauth_client_id=slack_oauth_client_id,
+            slack_oauth_client_secret=slack_oauth_client_secret,
             teams_team_id=teams_team_id,
             teams_command_script=teams_command_script,
             teams_team_name=teams_team_name,
