@@ -2,7 +2,7 @@ from enum import Enum
 
 
 class GetSuspendedJobFlowResponse200JobType1FlowStatusModulesItemAgentActionsItemType1Type(str, Enum):
-    MESSAGE = "message"
+    MCP_TOOL_CALL = "mcp_tool_call"
 
     def __str__(self) -> str:
         return str(self.value)
