@@ -16,7 +16,7 @@ class JobType0JobKind(str, Enum):
     PREVIEW = "preview"
     SCRIPT = "script"
     SCRIPT_HUB = "script_hub"
-    SINGLESCRIPTFLOW = "singlescriptflow"
+    SINGLESTEPFLOW = "singlestepflow"
 
     def __str__(self) -> str:
         return str(self.value)
