@@ -36,7 +36,7 @@ class KafkaTrigger:
         last_server_ping (Union[Unset, datetime.datetime]):
         error (Union[Unset, str]):
         error_handler_path (Union[Unset, str]):
-        error_handler_args (Union[Unset, KafkaTriggerErrorHandlerArgs]):
+        error_handler_args (Union[Unset, KafkaTriggerErrorHandlerArgs]): The arguments to pass to the script or flow
         retry (Union[Unset, KafkaTriggerRetry]):
     """
 
