@@ -49,7 +49,8 @@ class ListGcpTriggersResponse200Item:
         last_server_ping (Union[Unset, datetime.datetime]):
         error (Union[Unset, str]):
         error_handler_path (Union[Unset, str]):
-        error_handler_args (Union[Unset, ListGcpTriggersResponse200ItemErrorHandlerArgs]):
+        error_handler_args (Union[Unset, ListGcpTriggersResponse200ItemErrorHandlerArgs]): The arguments to pass to the
+            script or flow
         retry (Union[Unset, ListGcpTriggersResponse200ItemRetry]):
     """
 
