@@ -47,7 +47,8 @@ class ListMqttTriggersResponse200Item:
         last_server_ping (Union[Unset, datetime.datetime]):
         error (Union[Unset, str]):
         error_handler_path (Union[Unset, str]):
-        error_handler_args (Union[Unset, ListMqttTriggersResponse200ItemErrorHandlerArgs]):
+        error_handler_args (Union[Unset, ListMqttTriggersResponse200ItemErrorHandlerArgs]): The arguments to pass to the
+            script or flow
         retry (Union[Unset, ListMqttTriggersResponse200ItemRetry]):
     """
 
