@@ -1,10 +1,14 @@
-from typing import Any, Dict, List, Type, TypeVar, Union, cast
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
 
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.list_o_auth_logins_response_200_oauth_item import ListOAuthLoginsResponse200OauthItem
+
+
 T = TypeVar("T", bound="ListOAuthLoginsResponse200")
 
 
@@ -12,16 +16,20 @@ T = TypeVar("T", bound="ListOAuthLoginsResponse200")
 class ListOAuthLoginsResponse200:
     """
     Attributes:
-        oauth (List[str]):
+        oauth (List['ListOAuthLoginsResponse200OauthItem']):
         saml (Union[Unset, str]):
     """
 
-    oauth: List[str]
+    oauth: List["ListOAuthLoginsResponse200OauthItem"]
     saml: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
-        oauth = self.oauth
+        oauth = []
+        for oauth_item_data in self.oauth:
+            oauth_item = oauth_item_data.to_dict()
+
+            oauth.append(oauth_item)
 
         saml = self.saml
 
@@ -39,8 +47,15 @@ class ListOAuthLoginsResponse200:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.list_o_auth_logins_response_200_oauth_item import ListOAuthLoginsResponse200OauthItem
+
         d = src_dict.copy()
-        oauth = cast(List[str], d.pop("oauth"))
+        oauth = []
+        _oauth = d.pop("oauth")
+        for oauth_item_data in _oauth:
+            oauth_item = ListOAuthLoginsResponse200OauthItem.from_dict(oauth_item_data)
+
+            oauth.append(oauth_item)
 
         saml = d.pop("saml", UNSET)
 
