@@ -4,7 +4,7 @@ from attrs import define as _attrs_define
 from attrs import field as _attrs_field
 
 if TYPE_CHECKING:
-    from ..models.main_arg_signature_args_item_typ_type_3_object_item import MainArgSignatureArgsItemTypType3ObjectItem
+    from ..models.main_arg_signature_args_item_typ_type_3_object import MainArgSignatureArgsItemTypType3Object
 
 
 T = TypeVar("T", bound="MainArgSignatureArgsItemTypType3")
@@ -14,18 +14,14 @@ T = TypeVar("T", bound="MainArgSignatureArgsItemTypType3")
 class MainArgSignatureArgsItemTypType3:
     """
     Attributes:
-        object_ (List['MainArgSignatureArgsItemTypType3ObjectItem']):
+        object_ (MainArgSignatureArgsItemTypType3Object):
     """
 
-    object_: List["MainArgSignatureArgsItemTypType3ObjectItem"]
+    object_: "MainArgSignatureArgsItemTypType3Object"
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
-        object_ = []
-        for object_item_data in self.object_:
-            object_item = object_item_data.to_dict()
-
-            object_.append(object_item)
+        object_ = self.object_.to_dict()
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -39,17 +35,10 @@ class MainArgSignatureArgsItemTypType3:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
-        from ..models.main_arg_signature_args_item_typ_type_3_object_item import (
-            MainArgSignatureArgsItemTypType3ObjectItem,
-        )
+        from ..models.main_arg_signature_args_item_typ_type_3_object import MainArgSignatureArgsItemTypType3Object
 
         d = src_dict.copy()
-        object_ = []
-        _object_ = d.pop("object")
-        for object_item_data in _object_:
-            object_item = MainArgSignatureArgsItemTypType3ObjectItem.from_dict(object_item_data)
-
-            object_.append(object_item)
+        object_ = MainArgSignatureArgsItemTypType3Object.from_dict(d.pop("object"))
 
         main_arg_signature_args_item_typ_type_3 = cls(
             object_=object_,
