@@ -43,7 +43,7 @@ class MqttTrigger:
         last_server_ping (Union[Unset, datetime.datetime]):
         error (Union[Unset, str]):
         error_handler_path (Union[Unset, str]):
-        error_handler_args (Union[Unset, MqttTriggerErrorHandlerArgs]):
+        error_handler_args (Union[Unset, MqttTriggerErrorHandlerArgs]): The arguments to pass to the script or flow
         retry (Union[Unset, MqttTriggerRetry]):
     """
 
