@@ -25,7 +25,7 @@ class NewKafkaTrigger:
         topics (List[str]):
         enabled (Union[Unset, bool]):
         error_handler_path (Union[Unset, str]):
-        error_handler_args (Union[Unset, NewKafkaTriggerErrorHandlerArgs]):
+        error_handler_args (Union[Unset, NewKafkaTriggerErrorHandlerArgs]): The arguments to pass to the script or flow
         retry (Union[Unset, NewKafkaTriggerRetry]):
     """
 
