@@ -10,6 +10,7 @@ if TYPE_CHECKING:
     from ..models.open_flow_w_path_value_modules_item_retry_exponential import (
         OpenFlowWPathValueModulesItemRetryExponential,
     )
+    from ..models.open_flow_w_path_value_modules_item_retry_retry_if import OpenFlowWPathValueModulesItemRetryRetryIf
 
 
 T = TypeVar("T", bound="OpenFlowWPathValueModulesItemRetry")
@@ -21,10 +22,12 @@ class OpenFlowWPathValueModulesItemRetry:
     Attributes:
         constant (Union[Unset, OpenFlowWPathValueModulesItemRetryConstant]):
         exponential (Union[Unset, OpenFlowWPathValueModulesItemRetryExponential]):
+        retry_if (Union[Unset, OpenFlowWPathValueModulesItemRetryRetryIf]):
     """
 
     constant: Union[Unset, "OpenFlowWPathValueModulesItemRetryConstant"] = UNSET
     exponential: Union[Unset, "OpenFlowWPathValueModulesItemRetryExponential"] = UNSET
+    retry_if: Union[Unset, "OpenFlowWPathValueModulesItemRetryRetryIf"] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -36,6 +39,10 @@ class OpenFlowWPathValueModulesItemRetry:
         if not isinstance(self.exponential, Unset):
             exponential = self.exponential.to_dict()
 
+        retry_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.retry_if, Unset):
+            retry_if = self.retry_if.to_dict()
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update({})
@@ -43,6 +50,8 @@ class OpenFlowWPathValueModulesItemRetry:
             field_dict["constant"] = constant
         if exponential is not UNSET:
             field_dict["exponential"] = exponential
+        if retry_if is not UNSET:
+            field_dict["retry_if"] = retry_if
 
         return field_dict
 
@@ -54,6 +63,9 @@ class OpenFlowWPathValueModulesItemRetry:
         from ..models.open_flow_w_path_value_modules_item_retry_exponential import (
             OpenFlowWPathValueModulesItemRetryExponential,
         )
+        from ..models.open_flow_w_path_value_modules_item_retry_retry_if import (
+            OpenFlowWPathValueModulesItemRetryRetryIf,
+        )
 
         d = src_dict.copy()
         _constant = d.pop("constant", UNSET)
@@ -70,9 +82,17 @@ class OpenFlowWPathValueModulesItemRetry:
         else:
             exponential = OpenFlowWPathValueModulesItemRetryExponential.from_dict(_exponential)
 
+        _retry_if = d.pop("retry_if", UNSET)
+        retry_if: Union[Unset, OpenFlowWPathValueModulesItemRetryRetryIf]
+        if isinstance(_retry_if, Unset):
+            retry_if = UNSET
+        else:
+            retry_if = OpenFlowWPathValueModulesItemRetryRetryIf.from_dict(_retry_if)
+
         open_flow_w_path_value_modules_item_retry = cls(
             constant=constant,
             exponential=exponential,
+            retry_if=retry_if,
         )
 
         open_flow_w_path_value_modules_item_retry.additional_properties = d
