@@ -41,7 +41,7 @@ class QueuedJob:
         scheduled_for (Union[Unset, datetime.datetime]):
         script_path (Union[Unset, str]):
         script_hash (Union[Unset, str]):
-        args (Union[Unset, QueuedJobArgs]):
+        args (Union[Unset, QueuedJobArgs]): The arguments to pass to the script or flow
         logs (Union[Unset, str]):
         raw_code (Union[Unset, str]):
         canceled_by (Union[Unset, str]):
