@@ -31,6 +31,8 @@ class RunFlowPreviewAndWaitResultJsonBodyValue:
         concurrent_limit (Union[Unset, float]):
         concurrency_key (Union[Unset, str]):
         concurrency_time_window_s (Union[Unset, float]):
+        debounce_delay_s (Union[Unset, float]):
+        debounce_key (Union[Unset, str]):
         skip_expr (Union[Unset, str]):
         cache_ttl (Union[Unset, float]):
         priority (Union[Unset, float]):
@@ -45,6 +47,8 @@ class RunFlowPreviewAndWaitResultJsonBodyValue:
     concurrent_limit: Union[Unset, float] = UNSET
     concurrency_key: Union[Unset, str] = UNSET
     concurrency_time_window_s: Union[Unset, float] = UNSET
+    debounce_delay_s: Union[Unset, float] = UNSET
+    debounce_key: Union[Unset, str] = UNSET
     skip_expr: Union[Unset, str] = UNSET
     cache_ttl: Union[Unset, float] = UNSET
     priority: Union[Unset, float] = UNSET
@@ -71,6 +75,8 @@ class RunFlowPreviewAndWaitResultJsonBodyValue:
         concurrent_limit = self.concurrent_limit
         concurrency_key = self.concurrency_key
         concurrency_time_window_s = self.concurrency_time_window_s
+        debounce_delay_s = self.debounce_delay_s
+        debounce_key = self.debounce_key
         skip_expr = self.skip_expr
         cache_ttl = self.cache_ttl
         priority = self.priority
@@ -96,6 +102,10 @@ class RunFlowPreviewAndWaitResultJsonBodyValue:
             field_dict["concurrency_key"] = concurrency_key
         if concurrency_time_window_s is not UNSET:
             field_dict["concurrency_time_window_s"] = concurrency_time_window_s
+        if debounce_delay_s is not UNSET:
+            field_dict["debounce_delay_s"] = debounce_delay_s
+        if debounce_key is not UNSET:
+            field_dict["debounce_key"] = debounce_key
         if skip_expr is not UNSET:
             field_dict["skip_expr"] = skip_expr
         if cache_ttl is not UNSET:
@@ -153,6 +163,10 @@ class RunFlowPreviewAndWaitResultJsonBodyValue:
 
         concurrency_time_window_s = d.pop("concurrency_time_window_s", UNSET)
 
+        debounce_delay_s = d.pop("debounce_delay_s", UNSET)
+
+        debounce_key = d.pop("debounce_key", UNSET)
+
         skip_expr = d.pop("skip_expr", UNSET)
 
         cache_ttl = d.pop("cache_ttl", UNSET)
@@ -171,6 +185,8 @@ class RunFlowPreviewAndWaitResultJsonBodyValue:
             concurrent_limit=concurrent_limit,
             concurrency_key=concurrency_key,
             concurrency_time_window_s=concurrency_time_window_s,
+            debounce_delay_s=debounce_delay_s,
+            debounce_key=debounce_key,
             skip_expr=skip_expr,
             cache_ttl=cache_ttl,
             priority=priority,
